@@ -23,3 +23,10 @@ bootstrap HTML::HTPL::SQL $VERSION;
 # Autoload methods go after =cut, and are processed by the autosplit program.
 
 1;
+__END__
+
+#
+
+=head1 INTERNAL
+
+This module is internal for HTPL. It is useless to use directly.
